# Slot: class_uri


URI of the class in an RDF environment

URI: [http://w3id.org/biolink/biolinkml/meta/class_uri](slot_uri)
## Domain and Range

[ClassDefinition](ClassDefinition.md) -><sub>opt</sub> [Uri](Uri.md)
## Inheritance

## Children

## Used by

 * [ClassDefinition](ClassDefinition.md)
